@@ -602,6 +602,34 @@ class Node(_common.ListMixin, resource.Resource):
                 "the last error is %(error)s" %
                 {'node': self.id, 'error': self.last_error})
 
+    def inject_nmi(self, session):
+        """Inject NMI.
+
+        :param session: The session to use for making this request.
+        :return: None
+        """
+        session = self._get_session(session)
+        version = self._assert_microversion_for(
+            session,
+            'commit',
+            _common.INJECT_NMI_VERSION,
+        )
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(request.url, 'management', 'inject_nmi')
+
+        body = {}
+
+        response = session.put(
+            request.url,
+            json=body,
+            headers=request.headers,
+            microversion=version,
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
+        msg = ("Failed to inject NMI to node {node}".format(node=self.id))
+        exceptions.raise_from_response(response, error_message=msg)
+
     def set_power_state(self, session, target, wait=False, timeout=None):
         """Run an action modifying this node's power state.
 
@@ -834,6 +862,26 @@ class Node(_common.ListMixin, resource.Resource):
                .format(node=self.id))
         exceptions.raise_from_response(response, error_message=msg)
 
+    def get_boot_device(self, session):
+        session = self._get_session(session)
+        version = self._get_microversion(session, action='fetch')
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(request.url, 'management', 'boot_device')
+
+        response = session.get(
+            request.url,
+            headers=request.headers,
+            microversion=version,
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
+        msg = "Failed to get boot device for node {node}".format(
+            node=self.id,
+        )
+        exceptions.raise_from_response(response, error_message=msg)
+
+        return response.json()
+
     def set_boot_device(self, session, boot_device, persistent=False):
         """Set node boot device
 
@@ -858,6 +906,31 @@ class Node(_common.ListMixin, resource.Resource):
                .format(node=self.id))
         exceptions.raise_from_response(response, error_message=msg)
 
+    def get_supported_boot_devices(self, session):
+        session = self._get_session(session)
+        version = self._get_microversion(session, action='fetch')
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(
+            request.url,
+            'management',
+            'boot_device',
+            'supported',
+        )
+
+        response = session.get(
+            request.url,
+            headers=request.headers,
+            microversion=version,
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
+        msg = "Failed to get supported boot devices for node {node}".format(
+            node=self.id,
+        )
+        exceptions.raise_from_response(response, error_message=msg)
+
+        return response.json()
+
     def set_boot_mode(self, session, target):
         """Make a request to change node's boot mode
 
@@ -1052,6 +1125,52 @@ class Node(_common.ListMixin, resource.Resource):
 
         return response.json()
 
+    def get_console(self, session):
+        session = self._get_session(session)
+        version = self._get_microversion(session, action='fetch')
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(request.url, 'states', 'console')
+
+        response = session.get(
+            request.url,
+            headers=request.headers,
+            microversion=version,
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
+        msg = "Failed to get console for node {node}".format(
+            node=self.id,
+        )
+        exceptions.raise_from_response(response, error_message=msg)
+
+        return response.json()
+
+    def set_console_mode(self, session, enabled):
+        session = self._get_session(session)
+        version = self._get_microversion(session, action='commit')
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(request.url, 'states', 'console')
+        if not isinstance(enabled, bool):
+            raise ValueError(
+                "Invalid enabled %s. It should be True or False "
+                "corresponding to console enabled or disabled"
+                % enabled
+            )
+        body = {'enabled': enabled}
+
+        response = session.put(
+            request.url,
+            json=body,
+            headers=request.headers,
+            microversion=version,
+            retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
+        )
+
+        msg = "Failed to change console mode for {node}".format(
+            node=self.id,
+        )
+        exceptions.raise_from_response(response, error_message=msg)
+
     def patch(self, session, patch=None, prepend_key=True, has_body=True,
               retry_on_conflict=None, base_path=None, reset_interfaces=None):
 
