@@ -21,7 +21,6 @@ import warnings
 import dogpile.cache
 import keystoneauth1.exceptions
 import keystoneauth1.session
-import munch
 import requests.models
 import requestsexceptions
 
@@ -551,11 +550,11 @@ class _OpenStackCloudMixin:
 
     @property
     def current_project(self):
-        """Return a ``munch.Munch`` describing the current project"""
+        """Return a ``utils.Munch`` describing the current project"""
         return self._get_project_info()
 
     def _get_project_info(self, project_id=None):
-        project_info = munch.Munch(
+        project_info = utils.Munch(
             id=project_id,
             name=None,
             domain_id=None,
@@ -581,11 +580,11 @@ class _OpenStackCloudMixin:
 
     @property
     def current_location(self):
-        """Return a ``munch.Munch`` explaining the current cloud location."""
+        """Return a ``utils.Munch`` explaining the current cloud location."""
         return self._get_current_location()
 
     def _get_current_location(self, project_id=None, zone=None):
-        return munch.Munch(
+        return utils.Munch(
             cloud=self.name,
             # TODO(efried): This is wrong, but it only seems to be used in a
             # repr; can we get rid of it?
@@ -596,11 +595,11 @@ class _OpenStackCloudMixin:
 
     def _get_identity_location(self):
         '''Identity resources do not exist inside of projects.'''
-        return munch.Munch(
+        return utils.Munch(
             cloud=self.name,
             region_name=None,
             zone=None,
-            project=munch.Munch(
+            project=utils.Munch(
                 id=None,
                 name=None,
                 domain_id=None,
@@ -753,6 +752,77 @@ class _OpenStackCloudMixin:
         else:
             return False
 
+    def search_resources(
+        self,
+        resource_type,
+        name_or_id,
+        get_args=None,
+        get_kwargs=None,
+        list_args=None,
+        list_kwargs=None,
+        **filters
+    ):
+        """Search resources
+
+        Search resources matching certain conditions
+
+        :param str resource_type: String representation of the expected
+            resource as `service.resource` (i.e. "network.security_group").
+        :param str name_or_id: Name or ID of the resource
+        :param list get_args: Optional args to be passed to the _get call.
+        :param dict get_kwargs: Optional kwargs to be passed to the _get call.
+        :param list list_args: Optional args to be passed to the _list call.
+        :param dict list_kwargs: Optional kwargs to be passed to the _list call
+        :param dict filters: Additional filters to be used for querying
+            resources.
+        """
+        get_args = get_args or ()
+        get_kwargs = get_kwargs or {}
+        list_args = list_args or ()
+        list_kwargs = list_kwargs or {}
+
+        # User used string notation. Try to find proper
+        # resource
+        (service_name, resource_name) = resource_type.split('.')
+        if not hasattr(self, service_name):
+            raise exceptions.SDKException(
+                "service %s is not existing/enabled" %
+                service_name
+            )
+        service_proxy = getattr(self, service_name)
+        try:
+            resource_type = service_proxy._resource_registry[resource_name]
+        except KeyError:
+            raise exceptions.SDKException(
+                "Resource %s is not known in service %s" %
+                (resource_name, service_name)
+            )
+
+        if name_or_id:
+            # name_or_id is definitely not None
+            try:
+                resource_by_id = service_proxy._get(
+                    resource_type,
+                    name_or_id,
+                    *get_args,
+                    **get_kwargs)
+                return [resource_by_id]
+            except exceptions.ResourceNotFound:
+                pass
+
+        if not filters:
+            filters = {}
+
+        if name_or_id:
+            filters["name"] = name_or_id
+        list_kwargs.update(filters)
+
+        return list(service_proxy._list(
+            resource_type,
+            *list_args,
+            **list_kwargs
+        ))
+
     def project_cleanup(
         self,
         dry_run=True,
