@@ -20,7 +20,6 @@ import json
 import re
 
 from requests import exceptions as _rex
-import six
 
 
 class SDKException(Exception):
@@ -88,7 +87,7 @@ class HttpException(SDKException, _rex.HTTPError):
         if self.status_code is not None and (400 <= self.status_code < 500):
             self.source = "Client"
 
-    def __unicode__(self):
+    def __str__(self):
         # 'Error' is the default value for self.message. If self.message isn't
         # 'Error', then someone has set a more informative error message
         # and we should use it. If it is 'Error', then we should construct a
@@ -101,26 +100,33 @@ class HttpException(SDKException, _rex.HTTPError):
             if self.details:
                 remote_error += ', '
         if self.details:
-            remote_error += six.text_type(self.details)
+            remote_error += str(self.details)
 
         return "{message}: {remote_error}".format(
             message=super(HttpException, self).__str__(),
             remote_error=remote_error)
 
-    def __str__(self):
-        return self.__unicode__()
-
 
 class BadRequestException(HttpException):
     """HTTP 400 Bad Request."""
     pass
 
 
+class ForbiddenException(HttpException):
+    """HTTP 403 Forbidden Request."""
+    pass
+
+
 class ConflictException(HttpException):
     """HTTP 409 Conflict."""
     pass
 
 
+class PreconditionFailedException(HttpException):
+    """HTTP 412 Precondition Failed."""
+    pass
+
+
 class MethodNotSupported(SDKException):
     """The resource does not support this operation type."""
     def __init__(self, resource, method):
@@ -171,7 +177,7 @@ def _extract_message(obj):
         # Ironic starting with Stein
         elif obj.get('faultstring'):
             return obj['faultstring']
-    elif isinstance(obj, six.string_types):
+    elif isinstance(obj, str):
         # Ironic before Stein has double JSON encoding, nobody remembers why.
         try:
             obj = json.loads(obj)
@@ -186,12 +192,16 @@ def raise_from_response(response, error_message=None):
     if response.status_code < 400:
         return
 
-    if response.status_code == 409:
-        cls = ConflictException
+    if response.status_code == 400:
+        cls = BadRequestException
+    elif response.status_code == 403:
+        cls = ForbiddenException
     elif response.status_code == 404:
         cls = NotFoundException
-    elif response.status_code == 400:
-        cls = BadRequestException
+    elif response.status_code == 409:
+        cls = ConflictException
+    elif response.status_code == 412:
+        cls = PreconditionFailedException
     else:
         cls = HttpException
 
@@ -205,6 +215,9 @@ def raise_from_response(response, error_message=None):
         try:
             content = response.json()
             messages = [_extract_message(obj) for obj in content.values()]
+            if not any(messages):
+                # Exception dict may be the root dict in projects that use WSME
+                messages = [_extract_message(content)]
             # Join all of the messages together nicely and filter out any
             # objects that don't have a "message" attr.
             details = '\n'.join(msg for msg in messages if msg)
