@@ -17,13 +17,18 @@ from openstack import proxy
 
 
 class Proxy(proxy.Proxy):
+    _resource_registry = {
+        "container": _container.Container,
+        "order": _order.Order,
+        "secret": _secret.Secret,
+    }
 
     def create_container(self, **attrs):
         """Create a new container from attributes
 
         :param dict attrs: Keyword arguments which will be used to create
-               a :class:`~openstack.key_manager.v1.container.Container`,
-               comprised of the properties on the Container class.
+            a :class:`~openstack.key_manager.v1.container.Container`,
+            comprised of the properties on the Container class.
 
         :returns: The results of container creation
         :rtype: :class:`~openstack.key_manager.v1.container.Container`
@@ -34,13 +39,13 @@ class Proxy(proxy.Proxy):
         """Delete a container
 
         :param container: The value can be either the ID of a container or a
-               :class:`~openstack.key_manager.v1.container.Container`
-               instance.
+            :class:`~openstack.key_manager.v1.container.Container`
+            instance.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the container does not exist.
-                    When set to ``True``, no exception will be set when
-                    attempting to delete a nonexistent container.
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the container does not exist.
+            When set to ``True``, no exception will be set when
+            attempting to delete a nonexistent container.
 
         :returns: ``None``
         """
@@ -52,12 +57,12 @@ class Proxy(proxy.Proxy):
 
         :param name_or_id: The name or ID of a container.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the resource does not exist.
-                    When set to ``True``, None will be returned when
-                    attempting to find a nonexistent resource.
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the resource does not exist.
+            When set to ``True``, None will be returned when
+            attempting to find a nonexistent resource.
         :returns: One :class:`~openstack.key_manager.v1.container.Container`
-                  or None
+            or None
         """
         return self._find(_container.Container, name_or_id,
                           ignore_missing=ignore_missing)
@@ -66,12 +71,12 @@ class Proxy(proxy.Proxy):
         """Get a single container
 
         :param container: The value can be the ID of a container or a
-                      :class:`~openstack.key_manager.v1.container.Container`
-                      instance.
+            :class:`~openstack.key_manager.v1.container.Container`
+            instance.
 
         :returns: One :class:`~openstack.key_manager.v1.container.Container`
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         return self._get(_container.Container, container)
 
@@ -79,7 +84,7 @@ class Proxy(proxy.Proxy):
         """Return a generator of containers
 
         :param kwargs query: Optional query parameters to be sent to limit
-                                 the resources being returned.
+            the resources being returned.
 
         :returns: A generator of container objects
         :rtype: :class:`~openstack.key_manager.v1.container.Container`
@@ -90,10 +95,9 @@ class Proxy(proxy.Proxy):
         """Update a container
 
         :param container: Either the id of a container or a
-                      :class:`~openstack.key_manager.v1.container.Container`
-                      instance.
-        :attrs kwargs: The attributes to update on the container represented
-                       by ``value``.
+            :class:`~openstack.key_manager.v1.container.Container` instance.
+        :param attrs: The attributes to update on the container represented
+            by ``container``.
 
         :returns: The updated container
         :rtype: :class:`~openstack.key_manager.v1.container.Container`
@@ -104,8 +108,8 @@ class Proxy(proxy.Proxy):
         """Create a new order from attributes
 
         :param dict attrs: Keyword arguments which will be used to create
-                           a :class:`~openstack.key_manager.v1.order.Order`,
-                           comprised of the properties on the Order class.
+            a :class:`~openstack.key_manager.v1.order.Order`,
+            comprised of the properties on the Order class.
 
         :returns: The results of order creation
         :rtype: :class:`~openstack.key_manager.v1.order.Order`
@@ -116,13 +120,13 @@ class Proxy(proxy.Proxy):
         """Delete an order
 
         :param order: The value can be either the ID of a order or a
-                      :class:`~openstack.key_manager.v1.order.Order`
-                      instance.
+            :class:`~openstack.key_manager.v1.order.Order`
+            instance.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the order does not exist.
-                    When set to ``True``, no exception will be set when
-                    attempting to delete a nonexistent order.
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the order does not exist.
+            When set to ``True``, no exception will be set when
+            attempting to delete a nonexistent order.
 
         :returns: ``None``
         """
@@ -133,10 +137,10 @@ class Proxy(proxy.Proxy):
 
         :param name_or_id: The name or ID of a order.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the resource does not exist.
-                    When set to ``True``, None will be returned when
-                    attempting to find a nonexistent resource.
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the resource does not exist.
+            When set to ``True``, None will be returned when
+            attempting to find a nonexistent resource.
         :returns: One :class:`~openstack.key_manager.v1.order.Order` or None
         """
         return self._find(_order.Order, name_or_id,
@@ -146,12 +150,12 @@ class Proxy(proxy.Proxy):
         """Get a single order
 
         :param order: The value can be the ID of an order or a
-                      :class:`~openstack.key_manager.v1.order.Order`
-                      instance.
+            :class:`~openstack.key_manager.v1.order.Order`
+            instance.
 
         :returns: One :class:`~openstack.key_manager.v1.order.Order`
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         return self._get(_order.Order, order)
 
@@ -159,7 +163,7 @@ class Proxy(proxy.Proxy):
         """Return a generator of orders
 
         :param kwargs query: Optional query parameters to be sent to limit
-                                 the resources being returned.
+            the resources being returned.
 
         :returns: A generator of order objects
         :rtype: :class:`~openstack.key_manager.v1.order.Order`
@@ -170,10 +174,9 @@ class Proxy(proxy.Proxy):
         """Update a order
 
         :param order: Either the id of a order or a
-                      :class:`~openstack.key_manager.v1.order.Order`
-                      instance.
-        :attrs kwargs: The attributes to update on the order represented
-                       by ``value``.
+            :class:`~openstack.key_manager.v1.order.Order` instance.
+        :param attrs: The attributes to update on the order represented
+            by ``order``.
 
         :returns: The updated order
         :rtype: :class:`~openstack.key_manager.v1.order.Order`
@@ -184,8 +187,8 @@ class Proxy(proxy.Proxy):
         """Create a new secret from attributes
 
         :param dict attrs: Keyword arguments which will be used to create a
-                           :class:`~openstack.key_manager.v1.secret.Secret`,
-                           comprised of the properties on the Order class.
+            :class:`~openstack.key_manager.v1.secret.Secret`,
+            comprised of the properties on the Order class.
 
         :returns: The results of secret creation
         :rtype: :class:`~openstack.key_manager.v1.secret.Secret`
@@ -196,13 +199,13 @@ class Proxy(proxy.Proxy):
         """Delete a secret
 
         :param secret: The value can be either the ID of a secret or a
-                       :class:`~openstack.key_manager.v1.secret.Secret`
-                       instance.
+            :class:`~openstack.key_manager.v1.secret.Secret`
+            instance.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the secret does not exist.
-                    When set to ``True``, no exception will be set when
-                    attempting to delete a nonexistent secret.
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the secret does not exist.
+            When set to ``True``, no exception will be set when
+            attempting to delete a nonexistent secret.
 
         :returns: ``None``
         """
@@ -213,12 +216,12 @@ class Proxy(proxy.Proxy):
 
         :param name_or_id: The name or ID of a secret.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the resource does not exist.
-                    When set to ``True``, None will be returned when
-                    attempting to find a nonexistent resource.
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the resource does not exist.
+            When set to ``True``, None will be returned when
+            attempting to find a nonexistent resource.
         :returns: One :class:`~openstack.key_manager.v1.secret.Secret` or
-                  None
+            None
         """
         return self._find(_secret.Secret, name_or_id,
                           ignore_missing=ignore_missing)
@@ -227,12 +230,12 @@ class Proxy(proxy.Proxy):
         """Get a single secret
 
         :param secret: The value can be the ID of a secret or a
-                       :class:`~openstack.key_manager.v1.secret.Secret`
-                       instance.
+            :class:`~openstack.key_manager.v1.secret.Secret`
+            instance.
 
         :returns: One :class:`~openstack.key_manager.v1.secret.Secret`
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         return self._get(_secret.Secret, secret)
 
@@ -240,7 +243,7 @@ class Proxy(proxy.Proxy):
         """Return a generator of secrets
 
         :param kwargs query: Optional query parameters to be sent to limit
-                                 the resources being returned.
+            the resources being returned.
 
         :returns: A generator of secret objects
         :rtype: :class:`~openstack.key_manager.v1.secret.Secret`
@@ -251,10 +254,9 @@ class Proxy(proxy.Proxy):
         """Update a secret
 
         :param secret: Either the id of a secret or a
-                       :class:`~openstack.key_manager.v1.secret.Secret`
-                       instance.
-        :attrs kwargs: The attributes to update on the secret represented
-                       by ``value``.
+            :class:`~openstack.key_manager.v1.secret.Secret` instance.
+        :param attrs: The attributes to update on the secret represented
+            by ``secret``.
 
         :returns: The updated secret
         :rtype: :class:`~openstack.key_manager.v1.secret.Secret`
