@@ -9,12 +9,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from typing import List
 
+from openstack.common import tag
 from openstack.network.v2 import _base
 from openstack import resource
 
 
-class Port(_base.NetworkResource, resource.TagMixin):
+class Port(_base.NetworkResource, tag.TagMixin):
     resource_key = 'port'
     resources_key = 'ports'
     base_path = '/ports'
@@ -32,16 +34,17 @@ class Port(_base.NetworkResource, resource.TagMixin):
         'binding:vif_type', 'binding:vnic_type',
         'description', 'device_id', 'device_owner', 'fields', 'fixed_ips',
         'id', 'ip_address', 'mac_address', 'name', 'network_id', 'status',
-        'subnet_id',
+        'subnet_id', 'project_id',
         is_admin_state_up='admin_state_up',
         is_port_security_enabled='port_security_enabled',
-        project_id='tenant_id',
-        **resource.TagMixin._tag_query_parameters
+        **tag.TagMixin._tag_query_parameters
     )
 
     # Properties
-    #: Allowed address pairs.
-    allowed_address_pairs = resource.Body('allowed_address_pairs', type=list)
+    #: Allowed address pairs list. Dictionary key ``ip_address`` is required
+    #: and key ``mac_address`` is optional.
+    allowed_address_pairs: List[dict] = resource.Body('allowed_address_pairs',
+                                                      type=list)
     #: The ID of the host where the port is allocated. In some cases,
     #: different implementations can run on different hosts.
     binding_host_id = resource.Body('binding:host_id')
@@ -112,7 +115,9 @@ class Port(_base.NetworkResource, resource.TagMixin):
     numa_affinity_policy = resource.Body('numa_affinity_policy')
     #: The ID of the project who owns the network. Only administrative
     #: users can specify a project ID other than their own.
-    project_id = resource.Body('tenant_id')
+    project_id = resource.Body('project_id', alias='tenant_id')
+    #: Tenant_id (deprecated attribute).
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: Whether to propagate uplink status of the port. *Type: bool*
     propagate_uplink_status = resource.Body('propagate_uplink_status',
                                             type=bool)
