@@ -10,18 +10,16 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import six
 
 from openstack.tests.functional import base
 
 
 class TestAvailabilityZone(base.BaseFunctionalTest):
-
     def test_list(self):
-        availability_zones = list(self.conn.network.availability_zones())
-        self.assertGreater(len(availability_zones), 0)
+        availability_zones = list(self.user_cloud.network.availability_zones())
+        if len(availability_zones) > 0:
 
-        for az in availability_zones:
-            self.assertIsInstance(az.name, six.string_types)
-            self.assertIsInstance(az.resource, six.string_types)
-            self.assertIsInstance(az.state, six.string_types)
+            for az in availability_zones:
+                self.assertIsInstance(az.name, str)
+                self.assertIsInstance(az.resource, str)
+                self.assertIsInstance(az.state, str)
