@@ -29,20 +29,25 @@ class TestSegment(base.BaseFunctionalTest):
         super(TestSegment, self).setUp()
         self.NETWORK_NAME = self.getUniqueString()
 
+        if not self.operator_cloud:
+            self.skipTest("Operator cloud required for this test")
+
         # NOTE(rtheis): The segment extension is not yet enabled by default.
         # Skip the tests if not enabled.
-        if not self.conn.network.find_extension('segment'):
-            self.skipTest('Segment extension disabled')
+        if not self.operator_cloud.network.find_extension("segment"):
+            self.skipTest("Segment extension disabled")
 
         # Create a network to hold the segment.
-        net = self.conn.network.create_network(name=self.NETWORK_NAME)
+        net = self.operator_cloud.network.create_network(
+            name=self.NETWORK_NAME
+        )
         assert isinstance(net, network.Network)
         self.assertEqual(self.NETWORK_NAME, net.name)
         self.NETWORK_ID = net.id
 
         if self.SEGMENT_EXTENSION:
             # Get the segment for the network.
-            for seg in self.conn.network.segments():
+            for seg in self.operator_cloud.network.segments():
                 assert isinstance(seg, segment.Segment)
                 if self.NETWORK_ID == seg.network_id:
                     self.NETWORK_TYPE = seg.network_type
@@ -52,36 +57,36 @@ class TestSegment(base.BaseFunctionalTest):
                     break
 
     def tearDown(self):
-        sot = self.conn.network.delete_network(
-            self.NETWORK_ID,
-            ignore_missing=False)
+        sot = self.operator_cloud.network.delete_network(
+            self.NETWORK_ID, ignore_missing=False
+        )
         self.assertIsNone(sot)
         super(TestSegment, self).tearDown()
 
     def test_create_delete(self):
-        sot = self.conn.network.create_segment(
-            description='test description',
-            name='test name',
+        sot = self.operator_cloud.network.create_segment(
+            description="test description",
+            name="test name",
             network_id=self.NETWORK_ID,
-            network_type='geneve',
+            network_type="geneve",
             segmentation_id=2055,
         )
         self.assertIsInstance(sot, segment.Segment)
-        del_sot = self.conn.network.delete_segment(sot.id)
-        self.assertEqual('test description', sot.description)
-        self.assertEqual('test name', sot.name)
+        del_sot = self.operator_cloud.network.delete_segment(sot.id)
+        self.assertEqual("test description", sot.description)
+        self.assertEqual("test name", sot.name)
         self.assertEqual(self.NETWORK_ID, sot.network_id)
-        self.assertEqual('geneve', sot.network_type)
+        self.assertEqual("geneve", sot.network_type)
         self.assertIsNone(sot.physical_network)
         self.assertEqual(2055, sot.segmentation_id)
         self.assertIsNone(del_sot)
 
     def test_find(self):
-        sot = self.conn.network.find_segment(self.SEGMENT_ID)
+        sot = self.operator_cloud.network.find_segment(self.SEGMENT_ID)
         self.assertEqual(self.SEGMENT_ID, sot.id)
 
     def test_get(self):
-        sot = self.conn.network.get_segment(self.SEGMENT_ID)
+        sot = self.operator_cloud.network.get_segment(self.SEGMENT_ID)
         self.assertEqual(self.SEGMENT_ID, sot.id)
         self.assertIsNone(sot.name)
         self.assertEqual(self.NETWORK_ID, sot.network_id)
@@ -90,10 +95,11 @@ class TestSegment(base.BaseFunctionalTest):
         self.assertEqual(self.SEGMENTATION_ID, sot.segmentation_id)
 
     def test_list(self):
-        ids = [o.id for o in self.conn.network.segments(name=None)]
+        ids = [o.id for o in self.operator_cloud.network.segments(name=None)]
         self.assertIn(self.SEGMENT_ID, ids)
 
     def test_update(self):
-        sot = self.conn.network.update_segment(self.SEGMENT_ID,
-                                               description='update')
-        self.assertEqual('update', sot.description)
+        sot = self.operator_cloud.network.update_segment(
+            self.SEGMENT_ID, description="update"
+        )
+        self.assertEqual("update", sot.description)
