@@ -41,9 +41,15 @@ class TestVolume(TestVolumeProxy):
         self.verify_get(self.proxy.get_volume, volume.Volume)
 
     def test_volume_find(self):
-        self.verify_find(self.proxy.find_volume, volume.Volume,
-                         expected_kwargs=dict(
-                             list_base_path='/volumes/detail'))
+        self.verify_find(
+            self.proxy.find_volume,
+            volume.Volume,
+            method_kwargs={'all_projects': True},
+            expected_kwargs={
+                "list_base_path": "/volumes/detail",
+                "all_projects": True,
+            },
+        )
 
     def test_volumes_detailed(self):
         self.verify_list(
@@ -152,7 +158,11 @@ class TestGroup(TestVolumeProxy):
         self.verify_get(self.proxy.get_group, group.Group)
 
     def test_group_find(self):
-        self.verify_find(self.proxy.find_group, group.Group)
+        self.verify_find(
+            self.proxy.find_group,
+            group.Group,
+            expected_kwargs={'list_base_path': '/groups/detail'},
+        )
 
     def test_groups(self):
         self.verify_list(self.proxy.groups, group.Group)
@@ -192,7 +202,11 @@ class TestGroupSnapshot(TestVolumeProxy):
 
     def test_group_snapshot_find(self):
         self.verify_find(
-            self.proxy.find_group_snapshot, group_snapshot.GroupSnapshot
+            self.proxy.find_group_snapshot,
+            group_snapshot.GroupSnapshot,
+            expected_kwargs={
+                'list_base_path': '/group_snapshots/detail',
+            },
         )
 
     def test_group_snapshots(self):
@@ -556,7 +570,11 @@ class TestBackup(TestVolumeProxy):
         # NOTE: mock has_service
         self.proxy._connection = mock.Mock()
         self.proxy._connection.has_service = mock.Mock(return_value=True)
-        self.verify_find(self.proxy.find_backup, backup.Backup)
+        self.verify_find(
+            self.proxy.find_backup,
+            backup.Backup,
+            expected_kwargs={'list_base_path': '/backups/detail'},
+        )
 
     def test_backup_delete(self):
         # NOTE: mock has_service
@@ -612,7 +630,15 @@ class TestSnapshot(TestVolumeProxy):
         self.verify_get(self.proxy.get_snapshot, snapshot.Snapshot)
 
     def test_snapshot_find(self):
-        self.verify_find(self.proxy.find_snapshot, snapshot.Snapshot)
+        self.verify_find(
+            self.proxy.find_snapshot,
+            snapshot.Snapshot,
+            method_kwargs={'all_projects': True},
+            expected_kwargs={
+                'list_base_path': '/snapshots/detail',
+                'all_projects': True,
+            },
+        )
 
     def test_snapshots_detailed(self):
         self.verify_list(
