@@ -141,8 +141,8 @@ class TestClaim(base.TestCase):
             "queue": FAKE1["queue_name"], "claim": FAKE1["id"]}
         headers = {"Client-ID": "NEW_CLIENT_ID",
                    "X-PROJECT-ID": "NEW_PROJECT_ID"}
-        sess.get.assert_called_with(url,
-                                    headers=headers)
+        sess.get.assert_called_with(
+            url, headers=headers, skip_cache=False)
         sess.get_project_id.assert_called_once_with()
         sot._translate_response.assert_called_once_with(resp)
         self.assertEqual(sot, res)
@@ -160,8 +160,8 @@ class TestClaim(base.TestCase):
             "queue": FAKE2["queue_name"], "claim": FAKE2["id"]}
         headers = {"Client-ID": "OLD_CLIENT_ID",
                    "X-PROJECT-ID": "OLD_PROJECT_ID"}
-        sess.get.assert_called_with(url,
-                                    headers=headers)
+        sess.get.assert_called_with(
+            url, headers=headers, skip_cache=False)
         sot._translate_response.assert_called_once_with(resp)
         self.assertEqual(sot, res)
 
